pub struct RuntimeLoop { /* private fields */ }Implementations
Sourceimpl RuntimeLoop
impl RuntimeLoop
Sourcepub fn get_cancel_flag(&self) -> Arc<AtomicBool>
pub fn get_cancel_flag(&self) -> Arc<AtomicBool>
Sometimes we want to be able to cancel the loop from the outside. Before we start this loop in its own thread with run(), we can grab the cancel_flag and set it to true.
Sourcepub fn add_pollable(&mut self, pollable: Arc<Mutex<dyn PollableTrait>>)
pub fn add_pollable(&mut self, pollable: Arc<Mutex<dyn PollableTrait>>)
The runtime loop will continue to check a list of pollable closures. This is how you add such a closure.